==> pandoc-crossref-0.3.17.1-50-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.17.1
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.17.1-DJwOYYStEgk7Fjwv1YuNck-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.17.1-DJwOYYStEgk7Fjwv1YuNck-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  257fe03b3f54c20b0cdff2822132020d
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.17.1-DJwOYYStEgk7Fjwv1YuNck-pandoc-crossref-internal

depends:
    base-4.16.4.0 containers-0.6.5.1
    data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS directory-1.3.6.2
    filepath-1.4.2.2 microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-ghc-0.4.14.3-2BmMTTjNdLG3FnUhKIimXA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6 mtl-2.2.2
    pandoc-3.1.11.1-DLyXXWKTkBwJ6eULlhRtzB
    pandoc-types-1.23.1-3laIhw0CfokA8B8NVywYAe
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 template-haskell-2.18.0.0
    text-1.2.5.0 utility-ht-0.0.17.2-7aD59tOrIsvDwdKq8uQ8QL

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-crossref
version:              0.3.17.1
visibility:           public
id:                   pandoc-crossref-0.3.17.1-952zQrQsbaj3Vx43vCiGrb
key:                  pandoc-crossref-0.3.17.1-952zQrQsbaj3Vx43vCiGrb
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  2e3f6de624fbd901e6ee22e1a778c628
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.17.1-952zQrQsbaj3Vx43vCiGrb
depends:
    base-4.16.4.0 mtl-2.2.2 pandoc-3.1.11.1-DLyXXWKTkBwJ6eULlhRtzB
    pandoc-crossref-0.3.17.1-DJwOYYStEgk7Fjwv1YuNck-pandoc-crossref-internal
    pandoc-types-1.23.1-3laIhw0CfokA8B8NVywYAe text-1.2.5.0

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-crossref-0.3.17.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-pandoc-crossref-z-pandoc-crossref-internal
version:              0.3.17.1
package-name:         pandoc-crossref
lib-name:             pandoc-crossref-internal
id:
    pandoc-crossref-0.3.17.1-NPzqxkgvMR4rnVBhjwNtJ-pandoc-crossref-internal

key:
    pandoc-crossref-0.3.17.1-NPzqxkgvMR4rnVBhjwNtJ-pandoc-crossref-internal

license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  3b04da96cf8a31c66aed42d2df039ae2
exposed-modules:
    Text.Numeral.Roman Text.Pandoc.CrossRef.References
    Text.Pandoc.CrossRef.References.Blocks
    Text.Pandoc.CrossRef.References.Blocks.CodeBlock
    Text.Pandoc.CrossRef.References.Blocks.Header
    Text.Pandoc.CrossRef.References.Blocks.Math
    Text.Pandoc.CrossRef.References.Blocks.Subfigures
    Text.Pandoc.CrossRef.References.Blocks.Table
    Text.Pandoc.CrossRef.References.Blocks.Util
    Text.Pandoc.CrossRef.References.List
    Text.Pandoc.CrossRef.References.Monad
    Text.Pandoc.CrossRef.References.Refs
    Text.Pandoc.CrossRef.References.Types
    Text.Pandoc.CrossRef.Util.CodeBlockCaptions
    Text.Pandoc.CrossRef.Util.CustomLabels
    Text.Pandoc.CrossRef.Util.Meta Text.Pandoc.CrossRef.Util.ModifyMeta
    Text.Pandoc.CrossRef.Util.Options
    Text.Pandoc.CrossRef.Util.Settings
    Text.Pandoc.CrossRef.Util.Settings.Gen
    Text.Pandoc.CrossRef.Util.Settings.Template
    Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:
    HSpandoc-crossref-0.3.17.1-NPzqxkgvMR4rnVBhjwNtJ-pandoc-crossref-internal

depends:
    base-4.16.4.0 containers-0.6.5.1
    data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS directory-1.3.6.2
    filepath-1.4.2.2 microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    microlens-ghc-0.4.14.3-2BmMTTjNdLG3FnUhKIimXA
    microlens-mtl-0.2.0.3-K2j2D46quth4CyQpetHsMp
    microlens-th-0.4.3.15-BttKu46tg2TPgxEFeI4m6 mtl-2.2.2
    pandoc-3.1.11.1-EEyBabeW4095ZhVjvvY1k8
    pandoc-types-1.23.1-IHJEvc2SPdjQzihCSmUAO
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 template-haskell-2.18.0.0
    text-1.2.5.0 utility-ht-0.0.17.2-7aD59tOrIsvDwdKq8uQ8QL

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-crossref
version:              0.3.17.1
visibility:           public
id:                   pandoc-crossref-0.3.17.1-51tFI9O9IZGKLkH2NcpFah
key:                  pandoc-crossref-0.3.17.1-51tFI9O9IZGKLkH2NcpFah
license:              GPL-2.0-only
maintainer:           root@livid.pp.ru
author:               Nikolay Yakimov
homepage:             https://github.com/lierdakil/pandoc-crossref#readme
synopsis:             Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.

category:             Text
abi:                  27df5d6a5774cfe509e1085e3cddca59
exposed:              True
exposed-modules:      Text.Pandoc.CrossRef
import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-crossref-0.3.17.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-crossref
hs-libraries:         HSpandoc-crossref-0.3.17.1-51tFI9O9IZGKLkH2NcpFah
depends:
    base-4.16.4.0 mtl-2.2.2 pandoc-3.1.11.1-EEyBabeW4095ZhVjvvY1k8
    pandoc-crossref-0.3.17.1-NPzqxkgvMR4rnVBhjwNtJ-pandoc-crossref-internal
    pandoc-types-1.23.1-IHJEvc2SPdjQzihCSmUAO text-1.2.5.0

haddock-interfaces:   /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html:         /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
